@@ -26,7 +26,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <gnome.h>
+#include <libgnome/gnome-help.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include "actions.h"
 #include "dlg-add-files.h"
@@ -1515,7 +1515,7 @@ activate_action_about (GtkAction *action,
 		"Breda McColgan",
 		NULL
 	};
-	const char       *translator_credits = _("translator_credits");
+	const char       *translator_credits = _("translator-credits");
 
 
 	if (about != NULL) {
@@ -1527,11 +1527,11 @@ activate_action_about (GtkAction *action,
 	g_object_set (about,
 		      "name",  _("File Roller"),
 		      "version", VERSION,
-		      "copyright", "Copyright \xc2\xa9 2001-2004 Free Software Foundation, Inc.",
+		      "copyright", "Copyright \xc2\xa9 2001-2005 Free Software Foundation, Inc.",
 		      "comments", _("An archive manager for GNOME."),
 		      "authors", authors,
 		      "documenters", documenters,
-		      "translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		      "logo_icon_name", "file-roller",
 		      "website", NULL,
 		      "website_label", NULL,
