@@ -26,7 +26,6 @@
 #include <time.h>
 
 #include <glib.h>
-#include <gnome.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 
@@ -240,6 +239,10 @@ fr_command_rpm_new (FRProcess  *process,
 {
 	FRCommand *comm;
 
+	if (!is_program_in_path("rpm2cpio")) {
+		return NULL;
+	}
+
 	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_RPM, NULL));
 	fr_command_construct (comm, process, filename);
 
