@@ -22,15 +22,17 @@
 
 #include <config.h>
 
+#include <sys/types.h>
+#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <time.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
-#include <gnome.h>
 
 #include "file-data.h"
 #include "file-utils.h"
